aboutsummaryrefslogtreecommitdiffstats
path: root/Library/Homebrew/brew.h.rb
diff options
context:
space:
mode:
Diffstat (limited to 'Library/Homebrew/brew.h.rb')
-rw-r--r--Library/Homebrew/brew.h.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/Library/Homebrew/brew.h.rb b/Library/Homebrew/brew.h.rb
index a524c3298..f482559f6 100644
--- a/Library/Homebrew/brew.h.rb
+++ b/Library/Homebrew/brew.h.rb
@@ -97,8 +97,8 @@ def info name
user=''
user=`git config --global github.user`.chomp if system "which git > /dev/null"
user='mxcl' if user.empty?
- # FIXME it would be nice if we didn't assume the default branch is masterbrew
- history="http://github.com/#{user}/homebrew/commits/masterbrew/Library/Formula/#{Formula.path(name).basename}"
+ # FIXME it would be nice if we didn't assume the default branch is master
+ history="http://github.com/#{user}/homebrew/commits/master/Library/Formula/#{Formula.path(name).basename}"
exec 'open', history if ARGV.flag? '--github'